# tlid.py

from datetime import datetime

def get_tlid():
    fmt = "%y%m%d%H%M%S"
    return datetime.now().strftime(fmt)

def get_milliseconds():
    return datetime.now().strftime("%y%m%d%H%M%S%f")[:-3]

def get_seconds():
    return get_tlid()

def get_minutes():
    return datetime.now().strftime("%y%m%d%H%M")

def get_hour():
    return datetime.now().strftime("%y%m%d%H")

def get_day():
    return datetime.now().strftime("%y%m%d")

def get_month():
    return datetime.now().strftime("%y%m")

def get_year():
    return datetime.now().strftime("%y")

def extract_tlid(string):
    digits = ''.join(filter(str.isdigit, string))
    return digits if len(digits) in (12, 15) else None

def has_tlid(string):
    return extract_tlid(string) is not None

def clean_tlid(string):
    tlid = extract_tlid(string)
    return string.replace(tlid, '').strip() if tlid else string

def to_date(tlid_str):
    if len(tlid_str) == 12:
        return datetime.strptime(tlid_str, "%y%m%d%H%M%S")
    elif len(tlid_str) > 12:
        return datetime.strptime(tlid_str, "%y%m%d%H%M%S%f")
    elif len(tlid_str) == 8:
        return datetime.strptime(tlid_str, "%y%m%d%H")
    elif len(tlid_str) == 6:
        return datetime.strptime(tlid_str, "%y%m%d")
    elif len(tlid_str) == 10:
        return datetime.strptime(tlid_str, "%y%m%d%H%M")
    elif len(tlid_str) == 4:
        return datetime.strptime(tlid_str, "%y%m")
    else:
        raise ValueError("Invalid TLID string length.")



def tlid_dt_to_string(dt,no_seconds=True,year_two_digits=True):
    fmt = "%y%m%d%H%M"
    
    if year_two_digits is False:
        fmt="%Y%m%d%H%M"
        
    if no_seconds is False:
        fmt=fmt+"%S"
        
    return dt.strftime(fmt)

def tlid_dt_to_string_day(dt):
    return dt.strftime("%y%m%d")
def tlid_dt_to_string_seconds(dt):
    return dt.strftime("%y%m%d%H%M%SS")


def formatted_from_pto(dt, fmt):
    return dt.strftime(fmt)

def strdt(dt_str,no_seconds=True,year_two_digits=True):
    formats = ["%Y-%m-%d", "%Y-%m-%d %H", "%Y-%m-%d %H:%M", "%Y-%m-%d %H:%M:%S","%y-%m-%d", "%y-%m-%d %H", "%y-%m-%d %H:%M", "%y-%m-%d %H:%M:%S","%Y/%m/%d", "%Y/%m/%d %H", "%Y/%m/%d %H:%M", "%Y/%m/%d %H:%M:%S","%y/%m/%d", "%y/%m/%d %H", "%y/%m/%d %H:%M", "%y/%m/%d %H:%M:%S","%Y-%m-%d", "%Y-%m-%d %H", "%Y-%m-%d %H%M", "%Y-%m-%d %H%M%S","%y-%m-%d", "%y-%m-%d %H", "%y-%m-%d %H%M", "%y-%m-%d %H%M%S","%Y/%m/%d", "%Y/%m/%d %H", "%Y/%m/%d %H%M", "%Y/%m/%d %H%M%S","%y/%m/%d", "%y/%m/%d %H", "%y/%m/%d %H%M", "%y/%m/%d %H%M%S"]
    for fmt in formats:
        try:
            dtobj= datetime.strptime(dt_str, fmt)
            fixed_fmt = fmt.replace("-","").replace("/","").replace(":","").replace(" ","").replace("Y","y")
            #remove seconds '2019-01-01 00:00:00' 
            if no_seconds:
                fixed_fmt = fixed_fmt.replace("%S","")
            if year_two_digits:
                fixed_fmt = fixed_fmt.replace("%Y","%y")
            else:
                fixed_fmt = fixed_fmt.replace("%y","%Y")
            result=formatted_from_pto(dtobj, fixed_fmt)
            return result
        except ValueError:
            pass
    raise ValueError(f"no valid date format found for {dt_str}")

def fromdtstr(dt_str,no_seconds=True,year_two_digits=True):
    return strdt(dt_str,no_seconds,year_two_digits)



#!/usr/bin/env python
# tlidcli.py

import argparse
import sys
import os

sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))
#import tlid
#from . import tlid

from . import (
    get_minutes,
    get_hour,
    get_seconds,
    get_milliseconds,
    get_month,
    get_year,
    get_day,
    strdt,
)


def main():
    # Create the parser
    parser = argparse.ArgumentParser(
        description="TLID CLI - Generate time-based identifiers."
    )

    # Add arguments
    parser.add_argument(
        "unit",
        nargs="?",
        default="minutes",
        choices=["h", "s", "ms", "m", "M", "y", "d", "minutes","dt"],
        help="Select the unit of time for TLID generation (default: minutes).",
    )
    # Add nextarg argument
    parser.add_argument(
        "nextarg",
        nargs="?",
        default="",
        help="The next argument.",
    )

    # Parse the arguments
    args = parser.parse_args()

    # Get the TLID based on the selected unit
    if args.unit in ["h", "s", "ms", "m", "M", "y", "d", "minutes"]:
        
        if args.unit == "h" or args.unit == "H" or args.unit == "hour":
            print(get_hour())
        elif args.unit == "s" or args.unit == "S" or args.unit == "seconds":
            print(get_seconds())
        elif args.unit == "ms" or args.unit == "MS" or args.unit == "milliseconds":
            print(get_milliseconds())
        elif args.unit == "m" or args.unit == "month":
            print(get_month())
        elif args.unit == "y" or args.unit == "Y" or args.unit == "year":
            print(get_year())
        elif args.unit == "d" or args.unit == "D" or args.unit == "day":
            print(get_day())
        elif args.unit == "minutes" or args.unit == "min" or args.unit == "MINUTES":
            print(get_minutes())
    else:  
        print(strdt(args.nextarg))


# This is the standard boilerplate that calls the main() function.
if __name__ == "__main__":
    main()



# setup.py

from setuptools import setup, find_packages

setup(
    name='tlid',  # This should be a unique name, not already present on PyPI
    version='0.1.17',
    author='GUillaume Isabelle',
    author_email='jgi@jgwill.com',
    description='A utility for creating datetime-based strings for file naming in timeline.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/tlid/tlid/tree/master/src/python',  # Replace with the actual URL
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 2',
        'License :: OSI Approved :: MIT License',  # If your project is licensed under MIT
        'Operating System :: OS Independent',
    ],
    python_requires='>=2.7',
        entry_points={
        'console_scripts': [
            'pytlid=tlid.tlidcli:main',  # Assuming your tlidcli.py has a main() function
            'tlidpy=tlid.tlidcli:main',  # Assuming your tlidcli.py has a main() function
        ],
    },
)

